@@ -1,4 +1,5 @@
 use strict;
+use utf8;
 use Yandex::Translate;
 
 my $tr = Yandex::Translate->new;
@@ -8,8 +9,8 @@ $tr->set_key($key);
 
 # For more info please check set_default_ui in doc.
 $tr->set_default_ui('en');
-$tr->from_lang('en');
-$tr->to_lang('ru');
+$tr->set_from_lang('en');
+$tr->set_to_lang('ru');
 $tr->set_text('Hello Yandex');
 
 print $tr->translate(), "\n";
